@@ -23,7 +23,7 @@ class Keyword (Model):
 
 
 class Resource (Model):
-    # user = models.OneToOneField(settings.AUTH_USER_MODEL, null=True)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True)
     name = models.CharField(max_length=50, verbose_name="Resource Title")
     shortdesc = models.TextField(blank=True, null=True)
     longdesc = models.TextField(blank=True, null=True)
@@ -36,8 +36,8 @@ class Resource (Model):
     class Meta : 
         serializer_fields=["@id", "name", "shortdesc", "longdesc", "type", "img", "document",\
                            "link", "keywords"]
-        # auto_author = 'user'
-        # owner_field = 'user'
+        auto_author = 'user'
+        owner_field = 'user'
         container_path = 'resources/'
         rdf_type = 'hd:resource'
         anonymous_perms = ['view', 'add']
